@@ -4,7 +4,8 @@
 //! Cli module is only included in binary feature flag.
 
 use clap::clap_app;
-use crate::{error::RadError, processor::auth::AuthType};
+use crate::error::RadError;
+use crate::auth::AuthType;
 use crate::processor::Processor;
 use crate::utils::Utils;
 use std::path::{Path, PathBuf};
@@ -49,6 +50,7 @@ impl Cli {
             .greedy(args.is_present("greedy"))
             .strict(args.is_present("greedy"))
             .silent(args.is_present("silent"))
+            .nopanic(args.is_present("nopanic"))
             .allow(std::mem::replace(&mut self.allow_auth,None))
             .allow_with_warning(std::mem::replace(&mut self.allow_auth_warn,None))
             .unix_new_line(args.is_present("newline"))
@@ -70,6 +72,10 @@ impl Cli {
 
         // ========
         // Main options
+        // print permission
+        processor.print_permission()?;
+        
+        // Process
         // -->> Read from files
         if let Some(files) = args.values_of("FILE") {
             // Also read from stdin if given combiation option
@@ -112,7 +118,7 @@ impl Cli {
         } else { None };
 
         // Error to file 
-        self.error_to_file = if let Some(error_file) = args.value_of("error") {
+        self.error_to_file = if let Some(error_file) = args.value_of("err") {
             Some(PathBuf::from(error_file))
         } else { None };
 
@@ -154,17 +160,18 @@ impl Cli {
     /// Creates argument template wich clap macro
     fn args_builder() -> clap::ArgMatches {
         clap_app!(rad =>
-            (version: "0.8.5")
+            (version: "0.9.0")
             (author: "Simon Creek <simoncreek@tutanota.com>")
             (about: "R4d is a modern macro processor made with rust")
             (@arg FILE: ... "Files to execute processing")
             (@arg out: -o --out +takes_value "File to print out macro")
             (@arg err: -e --err +takes_value "File to save logs")
-            (@arg greedy: -g "Make all macro invocation greedy")
-            (@arg melt: ... -m +takes_value "Frozen file to reads")
-            (@arg freeze: -f +takes_value "Freeze to file")
-            (@arg purge: -p "Purge unused macros")
-            (@arg strict: -S "Strict mode")
+            (@arg greedy: -g --greedy "Make all macro invocation greedy")
+            (@arg melt: ... -m --melt +takes_value "Frozen file to reads")
+            (@arg freeze: -f --freeze +takes_value "Freeze to file")
+            (@arg purge: -p --purge "Purge unused macros")
+            (@arg nopanic: --nopanic "Allow panic")
+            (@arg strict: -S --strict "Strict mode")
             (@arg debug: -d --debug "Debug mode")
             (@arg log: -l --log "Debug log mode")
             (@arg interactive: -i --interactive "Use interactive debug mode")
@@ -174,7 +181,7 @@ impl Cli {
             (@arg allow_warn: -w +takes_value "Allow permission with warnings (fin|fout|cmd|env)")
             (@arg allow_all: -A "Allow all permission")
             (@arg allow_all_warn: -W "Allow all permission with warning")
-            (@arg silent: -s "Supress error and warning")
+            (@arg silent: -s "Supress warnings")
             (@arg newline: -n "Use unix newline for formatting")
         ).get_matches()
     }
