@@ -2,6 +2,9 @@ use crate::error::RadError;
 use regex::Regex;
 use std::io::BufRead;
 
+#[cfg(feature = "color")]
+use colored::*;
+
 pub(crate) struct Utils;
 
 impl Utils {
@@ -92,4 +95,53 @@ impl Utils {
         }
         return result;
     }
+    
+    pub fn green(string : &str) -> Box<dyn std::fmt::Display> {
+        if cfg!(feature = "color") {
+            #[cfg(feature = "color")]
+            return Box::new(string.green().to_owned());
+        }
+        Box::new(string.to_owned())
+    }
+
+    pub fn red(string : &str) -> Box<dyn std::fmt::Display> {
+        if cfg!(feature = "color") {
+            #[cfg(feature = "color")]
+            return Box::new(string.red().to_owned());
+        }
+        Box::new(string.to_owned())
+    }
+
+    pub fn yellow(string : &str) -> Box<dyn std::fmt::Display> {
+        if cfg!(feature = "color") {
+            #[cfg(feature = "color")]
+            return Box::new(string.yellow().to_owned());
+        }
+        Box::new(string.to_owned())
+    }
+    
+    // Copied from
+    // https://llogiq.github.io/2016/09/24/newline.html
+    // Actually the source talks about how to make following function faster
+    // yet I don't want to use simd because r4d's logic is currently very synchronous
+    // and making it a asynchornous would take much more effort and time
+    // NOTE : Trailing single is necessary because this only checks newline chracter
+    // thus line without trailing newline doesn't count as 1
+    /// Count new lines
+    #[allow(dead_code)]
+    pub(crate) fn count_sentences(s: &str) -> usize {
+        s.as_bytes().iter().filter(|&&c| c == b'\n').count() + 1
+    }
+
+    #[cfg(feature = "debug")]
+    /// Clear terminal cells
+    pub fn clear_terminal() -> Result<(), RadError> {
+        use crossterm::{ExecutableCommand, terminal::ClearType};
+
+        std::io::stdout()
+            .execute(crossterm::terminal::Clear(ClearType::All))?
+            .execute(crossterm::cursor::MoveTo(0,0))?;
+
+        Ok(())
+    }
 }
